@@ -6,6 +6,7 @@ regex.
 command_nodex: x means node?
 command_keys: ends with s means there can be multiple <key>
 """
+
 import logging
 from functools import lru_cache
 
@@ -200,6 +201,7 @@ LONGITUDE = rf"(?P<longitude>{_FLOAT})"
 LATITUDE = rf"(?P<latitude>{_FLOAT})"
 CURSOR = rf"(?P<cursor>{NUM})"
 PARAMETER = rf"(?P<parameter>{VALID_TOKEN})"
+PARAMETERS = rf"(?P<parameters>{VALID_TOKEN}(\s+{VALID_TOKEN})*)"
 DOUBLE_LUA = r'(?P<double_lua>[^"]*)'
 SINGLE_LUA = r"(?P<single_lua>[^']*)"
 INTTYPE = r"(?P<inttype>(i|u)\d+)"
@@ -384,10 +386,12 @@ GRAMMAR = {
     "command_slot_count": rf"\s+ {SLOT} \s+ {COUNT} \s*",
     "command_key_samples_count": rf"""
         \s+ {KEY} \s+ {SAMPLES} \s+ {COUNT} \s*""",
+    "command_key_samples_count_x": rf"\s+ {KEY} (\s+ {SAMPLES} \s+ {COUNT})? \s*",
     "command": r"\s*",
     "command_ip_port": rf"\s+ {IP} \s+ {PORT} \s*",
     "command_epoch": rf"\s+ {EPOCH} \s*",
     "command_yes": rf"\s+ {YES} \s*",
+    "command_on_off": rf"\s+ {ON_OFF} \s*",
     "command_sectionx": rf"(\s+ {SECTION})? \s*",
     "command_asyncx": rf"(\s+ {ASYNC})? \s*",
     "command_slot_slotsubcmd_nodex": rf"""
@@ -408,7 +412,10 @@ GRAMMAR = {
     "command_keys": rf"\s+ {KEYS} \s*",
     "command_key_value": rf"\s+ {KEY} \s+ {VALUE} \s*",
     "command_parameter_value": rf"\s+ {PARAMETER} \s+ {VALUE} \s*",
+    "command_parameter_values": rf"(\s+ {PARAMETER} \s+ {VALUE})+ \s*",
     "command_parameter": rf"\s+ {PARAMETER} \s+ {VALUE} \s*",
+    "command_parameters": rf"\s+ {PARAMETERS} \s*",
+    "command_parametersx": rf"(\s+ {PARAMETERS})? \s*",
     "command_value": rf"\s+ {VALUE} \s*",
     "command_key_second": rf"\s+ {KEY} \s+ {SECOND} \s*",
     "command_key_timestamp": rf"\s+ {KEY} \s+ {TIMESTAMP} \s*",
@@ -429,7 +436,10 @@ GRAMMAR = {
         \s+ {KEY} \s+ {VALUE}
         (
             (\s+ {EXPIRATION} \s+ {MILLISECOND})|
+            (\s+ {EXAT_CONST} \s+ {TIMESTAMP})|
+            (\s+ {PXAT_CONST} \s+ {TIMESTAMPMS})|
             (\s+ {CONDITION})|
+            (\s+ {GET})|
             (\s+ {KEEPTTL})
         )*
         \s*""",
@@ -481,10 +491,20 @@ GRAMMAR = {
         \s+ {KEY} \s+ {MIN} \s+ {MAX} (\s+ {WITHSCORES})?
         (\s+ {LIMIT} \s+ {OFFSET} \s+ {COUNT})? \s*""",
     "command_cursor_match_pattern_count_type": rf"""
-        \s+ {CURSOR} (\s+ {MATCH} \s+ {PATTERN})?
-        (\s+ {COUNT_CONST} \s+ {COUNT})? (\s+ {TYPE_CONST} \s+ {TYPE})? \s*""",
+        \s+ {CURSOR}
+        (
+            (\s+ {MATCH} \s+ {PATTERN})|
+            (\s+ {COUNT_CONST} \s+ {COUNT})|
+            (\s+ {TYPE_CONST} \s+ {TYPE})
+        )*
+        \s*""",
     "command_key_cursor_match_pattern_count": rf"""\s+ {KEY}
-        \s+ {CURSOR} (\s+ {MATCH} \s+ {PATTERN})? (\s+ {COUNT_CONST} \s+ {COUNT})? \s*""",
+        \s+ {CURSOR}
+        (
+            (\s+ {MATCH} \s+ {PATTERN})|
+            (\s+ {COUNT_CONST} \s+ {COUNT})
+        )*
+        \s*""",
     "command_key_fields": rf"\s+ {KEY} \s+ {FIELDS} \s*",
     "command_key_field": rf"\s+ {KEY} \s+ {FIELD} \s*",
     "command_key_field_delta": rf"\s+ {KEY} \s+ {FIELD} \s+ {DELTA} \s*",
@@ -516,8 +536,10 @@ GRAMMAR = {
     "command_restore": rf"""\s+ {KEY}
         \s+ {TIMEOUT} \s+ {VALUE} (\s+ {SUBRESTORE} \s+ {SECOND})? \s*""",
     "command_pubsubcmd_channels": rf"\s+ {PUBSUBCMD} (\s+ {CHANNEL})+ \s*",
+    "command_pubsubcmd_channelsx": rf"\s+ {PUBSUBCMD} (\s+ {CHANNEL})* \s*",
     "command_channel_message": rf"\s+ {CHANNEL} \s+ {MESSAGE} \s*",
     "command_channels": rf"(\s+ {CHANNEL})+ \s*",
+    "command_channelsx": rf"(\s+ {CHANNEL})* \s*",
     "command_lua_any": rf"""(\s+"{DOUBLE_LUA}")? (\s+'{SINGLE_LUA}')? \s+ {ANY} \s*""",
     "command_scriptdebug": rf"\s+ {SCRIPTDEBUG} \s*",
     "command_shutdown": rf"\s+ {SHUTDOWN} \s*",
@@ -619,6 +641,7 @@ GRAMMAR = {
     "command_username": rf"\s+ {USERNAME} \s*",
     "command_count_or_resetx": rf"( (\s+ {COUNT}) | (\s+ {RESET_CONST}) )? \s*",
     "command_username_rules": rf"\s+ {USERNAME} (\s+ {RULE})* \s*",
+    "command_username_parameter_parametersx": rf"\s+ {USERNAME} \s+ {PARAMETER} (\s+ {PARAMETERS})? \s*",
     "command_count": rf"(\s+ {COUNT})? \s*",
     "command_stralgo": rf"""
         (
@@ -645,6 +668,9 @@ GRAMMAR = {
         \s+ {KEY} \s+ {KEY}
         \s+ {LR_CONST} \s+ {LR_CONST}
         \s+ {TIMEOUT} \s*""",
+    "command_key_key_lr_lr": rf"""
+        \s+ {KEY} \s+ {KEY}
+        \s+ {LR_CONST} \s+ {LR_CONST} \s*""",
     "command_copy": rf"""
         \s+ {KEY} \s+ {KEY}
         (\s+ {DB_CONST} \s+ {INDEX})?
