@@ -107,6 +107,42 @@ def test_scan(judge_command):
             "type": "string",
         },
     )
+    # Test different parameter orders (Redis allows any order)
+    judge_command(
+        "SCAN 0 COUNT 15 MATCH task*",
+        {
+            "command": "SCAN",
+            "cursor": "0",
+            "count_const": "COUNT",
+            "count": "15",
+            "match": "MATCH",
+            "pattern": "task*",
+        },
+    )
+    judge_command(
+        "SCAN 0 TYPE string MATCH task*",
+        {
+            "command": "SCAN",
+            "cursor": "0",
+            "type_const": "TYPE",
+            "type": "string",
+            "match": "MATCH",
+            "pattern": "task*",
+        },
+    )
+    judge_command(
+        "SCAN 0 TYPE string COUNT 15 MATCH task*",
+        {
+            "command": "SCAN",
+            "cursor": "0",
+            "type_const": "TYPE",
+            "type": "string",
+            "count_const": "COUNT",
+            "count": "15",
+            "match": "MATCH",
+            "pattern": "task*",
+        },
+    )
 
 
 def test_migrate(judge_command):
@@ -157,9 +193,15 @@ def test_migrate(judge_command):
 
 
 def test_object(judge_command):
+    """OBJECT HELP (no args) and OBJECT ENCODING/REFCOUNT key (per commands.json)."""
+    judge_command("OBJECT HELP", {"command": "OBJECT HELP"})
+    judge_command(
+        "object encoding mylist",
+        {"command": "object encoding", "any": "mylist"},
+    )
     judge_command(
         "object refcount mylist",
-        {"command": "object", "object": "refcount", "key": "mylist"},
+        {"command": "object refcount", "any": "mylist"},
     )
 
 
