@@ -1,3 +1,29 @@
+def test_lpop_rpop(judge_command):
+    """LPOP/RPOP accept key and optional count (per commands.json since 6.2)."""
+    judge_command("LPOP mylist", {"command": "LPOP", "key": "mylist"})
+    judge_command(
+        "LPOP mylist 3",
+        {"command": "LPOP", "key": "mylist", "count": "3"},
+    )
+    judge_command("RPOP mylist", {"command": "RPOP", "key": "mylist"})
+    judge_command(
+        "RPOP mylist 2",
+        {"command": "RPOP", "key": "mylist", "count": "2"},
+    )
+
+
+def test_rpushx(judge_command):
+    """RPUSHX accepts key and one or more elements (per commands.json since 4.0)."""
+    judge_command(
+        "RPUSHX mylist a",
+        {"command": "RPUSHX", "key": "mylist", "values": "a"},
+    )
+    judge_command(
+        "RPUSHX mylist a b c",
+        {"command": "RPUSHX", "key": "mylist", "values": "a b c"},
+    )
+
+
 def test_rpush(judge_command):
     judge_command(
         "RPUSH list1 foo bar hello world",
@@ -120,6 +146,26 @@ def test_lpos(judge_command):
     )
 
 
+def test_lmove(judge_command):
+    """LMOVE (since 6.2) source dest LEFT|RIGHT LEFT|RIGHT (per commands.json)."""
+    judge_command(
+        "LMOVE src dest LEFT RIGHT",
+        {
+            "command": "LMOVE",
+            "key": ["src", "dest"],
+            "lr_const": ["LEFT", "RIGHT"],
+        },
+    )
+    judge_command(
+        "LMOVE mylist other RIGHT LEFT",
+        {
+            "command": "LMOVE",
+            "key": ["mylist", "other"],
+            "lr_const": ["RIGHT", "LEFT"],
+        },
+    )
+
+
 def test_blmove(judge_command):
     judge_command(
         "blmove list1 list2 left right 1.2",
